package org.jboss.soa.qa.hl7binging;

/**
 * URL builder for MINA2 camel client.
 */
public final class MinaUrlBuilder {

	private MinaUrlBuilder() {
	}

	/**
	 * Build localhost MINA2 url.
	 * @param port port of MINA service
	 * @param sync sync request (true = response expected)
	 * @param codec MINA codec
	 * @return url
	 */
	public static String build(final int port, final boolean sync, final String codec) {
		return build("127.0.0.1", port, sync, codec);
	}

	/**
	 * Build localhost MINA2 url.
	 * @param host server host address
	 * @param port port of MINA service
	 * @param sync sync request (true = response expected)
	 * @param codec MINA codec
	 * @return url
	 */
	public static String build(final String host, final int port, final boolean sync, final String codec) {
		final StringBuilder sb = new StringBuilder("mina2:tcp://").append(host).append(":").append(port).append("?");
		sb.append("sync=").append(sync).append("&");
		sb.append("codec=#").append(codec);
		return sb.toString();
	}
}
